@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -33,7 +33,7 @@ public class BindTargets extends Task {
 
     private String extensionPoint;
 
-    private final List<String> targets = new ArrayList<String>();
+    private final List<String> targets = new ArrayList<>();
 
     private OnMissingExtensionPoint onMissingExtensionPoint;
 
@@ -65,15 +65,14 @@ public class BindTargets extends Task {
         }
 
         if (getOwningTarget() == null
-                || !"".equals(getOwningTarget().getName())) {
-            throw new BuildException(
-                    "bindtargets only allowed as a top-level task");
+                || !getOwningTarget().getName().isEmpty()) {
+            throw new BuildException("bindtargets only allowed as a top-level task");
         }
 
         if (onMissingExtensionPoint == null) {
             onMissingExtensionPoint = OnMissingExtensionPoint.FAIL;
         }
-        final ProjectHelper helper = (ProjectHelper) getProject().getReference(
+        final ProjectHelper helper = getProject().getReference(
                 ProjectHelper.PROJECTHELPER_REFERENCE);
 
         for (String target : targets) {
