@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,8 +20,6 @@ package org.apache.tools.ant.taskdefs;
 
 import java.io.File;
 import java.io.IOException;
-import java.io.PrintWriter;
-import java.io.StringWriter;
 import java.util.Vector;
 
 import org.apache.tools.ant.BuildException;
@@ -40,6 +38,7 @@ import org.apache.tools.ant.types.PropertySet;
 import org.apache.tools.ant.types.RedirectorElement;
 import org.apache.tools.ant.types.Reference;
 import org.apache.tools.ant.util.KeepAliveInputStream;
+import org.apache.tools.ant.util.StringUtils;
 
 /**
  * Launcher for Java applications. Allows use of
@@ -51,6 +50,8 @@ import org.apache.tools.ant.util.KeepAliveInputStream;
  * @ant.task category="java"
  */
 public class Java extends Task {
+    private static final String TIMEOUT_MESSAGE =
+            "Timeout: killed the sub-process";
 
     private CommandlineJava cmdl = new CommandlineJava();
     private Environment env = new Environment();
@@ -77,9 +78,6 @@ public class Java extends Task {
     private boolean spawn = false;
     private boolean incompatibleWithSpawn = false;
 
-    private static final String TIMEOUT_MESSAGE =
-        "Timeout: killed the sub-process";
-
     /**
      * Normal constructor
      */
@@ -99,6 +97,7 @@ public class Java extends Task {
      * @throws BuildException if failOnError is set to true and the application
      * returns a nonzero result code.
      */
+    @Override
     public void execute() throws BuildException {
         File savedDir = dir;
         Permissions savedPermissions = perm;
@@ -142,30 +141,41 @@ public class Java extends Task {
      */
     protected void checkConfiguration() throws BuildException {
         String classname = getCommandLine().getClassname();
-        if (classname == null && getCommandLine().getJar() == null) {
+        String module = getCommandLine().getModule();
+        final String sourceFile = getCommandLine().getSourceFile();
+        if (classname == null && getCommandLine().getJar() == null && module == null && sourceFile == null) {
             throw new BuildException("Classname must not be null.");
         }
         if (!fork && getCommandLine().getJar() != null) {
-            throw new BuildException("Cannot execute a jar in non-forked mode."
-                                     + " Please set fork='true'. ");
+            throw new BuildException(
+                "Cannot execute a jar in non-forked mode. Please set fork='true'. ");
+        }
+        if (!fork && getCommandLine().getModule() != null) {
+            throw new BuildException(
+                "Cannot execute a module in non-forked mode. Please set fork='true'. ");
+        }
+        if (!fork && sourceFile != null) {
+            throw new BuildException("Cannot execute sourcefile in non-forked mode. Please set fork='true'");
         }
         if (spawn && !fork) {
-            throw new BuildException("Cannot spawn a java process in non-forked mode."
-                                     + " Please set fork='true'. ");
+            throw new BuildException(
+                "Cannot spawn a java process in non-forked mode. Please set fork='true'. ");
         }
         if (getCommandLine().getClasspath() != null
             && getCommandLine().getJar() != null) {
-            log("When using 'jar' attribute classpath-settings are ignored. "
-                + "See the manual for more information.", Project.MSG_VERBOSE);
+            log("When using 'jar' attribute classpath-settings are ignored. See the manual for more information.",
+                Project.MSG_VERBOSE);
         }
         if (spawn && incompatibleWithSpawn) {
-            getProject().log("spawn does not allow attributes related to input, "
-            + "output, error, result", Project.MSG_ERR);
+            getProject().log(
+                "spawn does not allow attributes related to input, output, error, result",
+                Project.MSG_ERR);
             getProject().log("spawn also does not allow timeout", Project.MSG_ERR);
-            getProject().log("finally, spawn is not compatible "
-                + "with a nested I/O <redirector>", Project.MSG_ERR);
-            throw new BuildException("You have used an attribute "
-                + "or nested element which is not compatible with spawn");
+            getProject().log(
+                "finally, spawn is not compatible with a nested I/O <redirector>",
+                Project.MSG_ERR);
+            throw new BuildException(
+                "You have used an attribute or nested element which is not compatible with spawn");
         }
         if (getCommandLine().getAssertions() != null && !fork) {
             log("Assertion statements are currently ignored in non-forked mode");
@@ -185,8 +195,8 @@ public class Java extends Task {
                     Project.MSG_WARN);
             }
             if (newEnvironment || null != env.getVariables()) {
-                log("Changes to environment variables are ignored when same "
-                    + "JVM is used.", Project.MSG_WARN);
+                log("Changes to environment variables are ignored when same JVM is used.",
+                    Project.MSG_WARN);
             }
             if (getCommandLine().getBootclasspath() != null) {
                 log("bootclasspath ignored when same JVM is used.",
@@ -211,19 +221,17 @@ public class Java extends Task {
     protected int executeJava(CommandlineJava commandLine) {
         try {
             if (fork) {
-                if (!spawn) {
-                    return fork(commandLine.getCommandline());
-                } else {
+                if (spawn) {
                     spawn(commandLine.getCommandline());
                     return 0;
                 }
-            } else {
-                try {
-                    run(commandLine);
-                    return 0;
-                } catch (ExitException ex) {
-                    return ex.getStatus();
-                }
+                return fork(commandLine.getCommandline());
+            }
+            try {
+                run(commandLine);
+                return 0;
+            } catch (ExitException ex) {
+                return ex.getStatus();
             }
         } catch (BuildException e) {
             if (e.getLocation() == null && getLocation() != null) {
@@ -231,23 +239,21 @@ public class Java extends Task {
             }
             if (failOnError) {
                 throw e;
-            } else {
-                if (TIMEOUT_MESSAGE.equals(e.getMessage())) {
-                    log(TIMEOUT_MESSAGE);
-                } else {
-                    log(e);
-                }
-                return -1;
             }
+            if (TIMEOUT_MESSAGE.equals(e.getMessage())) {
+                log(TIMEOUT_MESSAGE);
+            } else {
+                log(e);
+            }
+            return -1;
         } catch (ThreadDeath t) {
             throw t; // cf. NB #47191
         } catch (Throwable t) {
             if (failOnError) {
                 throw new BuildException(t, getLocation());
-            } else {
-                log(t);
-                return -1;
             }
+            log(t);
+            return -1;
         }
     }
 
@@ -289,6 +295,46 @@ public class Java extends Task {
         return getCommandLine().createBootclasspath(getProject()).createPath();
     }
 
+    /**
+     * Set the modulepath to be used when running the Java class.
+     *
+     * @param mp an Ant Path object containing the modulepath.
+     * @since 1.9.7
+     */
+    public void setModulepath(Path mp) {
+        createModulepath().append(mp);
+    }
+
+    /**
+     * Add a path to the modulepath.
+     *
+     * @return created modulepath.
+     * @since 1.9.7
+     */
+    public Path createModulepath() {
+        return getCommandLine().createModulepath(getProject()).createPath();
+    }
+
+    /**
+     * Set the modulepath to use by reference.
+     *
+     * @param r a reference to an existing modulepath.
+     * @since 1.9.7
+     */
+    public void setModulepathRef(Reference r) {
+        createModulepath().setRefid(r);
+    }
+
+    /**
+     * Add a path to the upgrademodulepath.
+     *
+     * @return created upgrademodulepath.
+     * @since 1.9.7
+     */
+    public Path createUpgrademodulepath() {
+        return getCommandLine().createUpgrademodulepath(getProject()).createPath();
+    }
+
     /**
      * Set the permissions for the application run inside the same JVM.
      * @since Ant 1.6
@@ -313,12 +359,14 @@ public class Java extends Task {
      *
      * @param jarfile the jarfile to execute.
      *
-     * @throws BuildException if there is also a main class specified.
+     * @throws BuildException if there is also a {@code classname}, {@code module}
+     *              or {@code sourcefile} attribute specified
      */
     public void setJar(File jarfile) throws BuildException {
-        if (getCommandLine().getClassname() != null) {
-            throw new BuildException("Cannot use 'jar' and 'classname' "
-                                     + "attributes in same command.");
+        if (getCommandLine().getClassname() != null || getCommandLine().getModule() != null
+                || getCommandLine().getSourceFile() != null) {
+            throw new BuildException(
+                    "Cannot use combination of 'jar', 'sourcefile', 'classname', 'module' attributes in same command");
         }
         getCommandLine().setJar(jarfile.getAbsolutePath());
     }
@@ -328,16 +376,52 @@ public class Java extends Task {
      *
      * @param s the name of the main class.
      *
-     * @throws BuildException if the jar attribute has been set.
+     * @throws BuildException if there is also a {@code jar} or {@code sourcefile} attribute specified
      */
     public void setClassname(String s) throws BuildException {
-        if (getCommandLine().getJar() != null) {
-            throw new BuildException("Cannot use 'jar' and 'classname' "
-                                     + "attributes in same command");
+        if (getCommandLine().getJar() != null || getCommandLine().getSourceFile() != null) {
+            throw new BuildException(
+                "Cannot use combination of 'jar', 'classname', sourcefile attributes in same command");
         }
         getCommandLine().setClassname(s);
     }
 
+    /**
+     * Set the Java module to execute.
+     *
+     * @param module the name of the module.
+     *
+     * @throws BuildException if there is also a {@code jar} or {@code sourcefile} attribute specified
+     * @since 1.9.7
+     */
+    public void setModule(String module) throws BuildException {
+        if (getCommandLine().getJar() != null || getCommandLine().getSourceFile() != null) {
+            throw new BuildException(
+                    "Cannot use combination of 'jar', 'module', sourcefile attributes in same command");
+        }
+        getCommandLine().setModule(module);
+    }
+
+    /**
+     * Set the Java source-file to execute. Support for single file source program
+     * execution, in Java, is only available since Java 11.
+     *
+     * @param sourceFile The path to the source file
+     * @throws BuildException if there is also a {@code jar}, {@code classname}
+     *              or {@code module} attribute specified
+     * @since Ant 1.10.5
+     */
+    public void setSourceFile(final String sourceFile) throws BuildException {
+        final String jar = getCommandLine().getJar();
+        final String className = getCommandLine().getClassname();
+        final String module = getCommandLine().getModule();
+        if (jar != null || className != null || module != null) {
+            throw new BuildException("Cannot use 'sourcefile' in combination with 'jar' or " +
+                    "'module' or 'classname'");
+        }
+        getCommandLine().setSourceFile(sourceFile);
+    }
+
     /**
      * Deprecated: use nested arg instead.
      * Set the command line arguments for the class.
@@ -347,8 +431,8 @@ public class Java extends Task {
      * @ant.attribute ignore="true"
      */
     public void setArgs(String s) {
-        log("The args attribute is deprecated. "
-            + "Please use nested arg elements.", Project.MSG_WARN);
+        log("The args attribute is deprecated. Please use nested arg elements.",
+            Project.MSG_WARN);
         getCommandLine().createArgument().setLine(s);
     }
 
@@ -415,8 +499,8 @@ public class Java extends Task {
      * @param s jvmargs.
      */
     public void setJvmargs(String s) {
-        log("The jvmargs attribute is deprecated. "
-            + "Please use nested jvmarg elements.", Project.MSG_WARN);
+        log("The jvmargs attribute is deprecated. Please use nested jvmarg elements.",
+            Project.MSG_WARN);
         getCommandLine().createVmArgument().setLine(s);
     }
 
@@ -497,8 +581,8 @@ public class Java extends Task {
      */
     public void setInput(File input) {
         if (inputString != null) {
-            throw new BuildException("The \"input\" and \"inputstring\" "
-                + "attributes cannot both be specified");
+            throw new BuildException(
+                "The \"input\" and \"inputstring\" attributes cannot both be specified");
         }
         this.input = input;
         incompatibleWithSpawn = true;
@@ -511,8 +595,8 @@ public class Java extends Task {
      */
     public void setInputString(String inputString) {
         if (input != null) {
-            throw new BuildException("The \"input\" and \"inputstring\" "
-                + "attributes cannot both be specified");
+            throw new BuildException(
+                "The \"input\" and \"inputstring\" attributes cannot both be specified");
         }
         this.inputString = inputString;
         incompatibleWithSpawn = true;
@@ -666,6 +750,7 @@ public class Java extends Task {
      *
      * @since Ant 1.5
      */
+    @Override
     protected void handleOutput(String output) {
         if (redirector.getOutputStream() != null) {
             redirector.handleOutput(output);
@@ -686,6 +771,7 @@ public class Java extends Task {
      * @exception IOException if the data cannot be read.
      * @since Ant 1.6
      */
+    @Override
     public int handleInput(byte[] buffer, int offset, int length)
         throws IOException {
         // Should work whether or not redirector.inputStream == null:
@@ -699,6 +785,7 @@ public class Java extends Task {
      *
      * @since Ant 1.5.2
      */
+    @Override
     protected void handleFlush(String output) {
         if (redirector.getOutputStream() != null) {
             redirector.handleFlush(output);
@@ -714,6 +801,7 @@ public class Java extends Task {
      *
      * @since Ant 1.5
      */
+    @Override
     protected void handleErrorOutput(String output) {
         if (redirector.getErrorStream() != null) {
             redirector.handleErrorOutput(output);
@@ -729,6 +817,7 @@ public class Java extends Task {
      *
      * @since Ant 1.5.2
      */
+    @Override
     protected void handleErrorFlush(String output) {
         if (redirector.getErrorStream() != null) {
             redirector.handleErrorFlush(output);
@@ -780,7 +869,7 @@ public class Java extends Task {
     }
 
     /**
-     * Executes the given classname with the given arguments in a separate VM.
+     * Executes the given source-file or classname with the given arguments in a separate VM.
      * @param command String[] of command-line arguments.
      */
     private int fork(String[] command) throws BuildException {
@@ -835,8 +924,8 @@ public class Java extends Task {
     private void setupEnvironment(Execute exe) {
         String[] environment = env.getVariables();
         if (environment != null) {
-            for (int i = 0; i < environment.length; i++) {
-                log("Setting environment variable: " + environment[i],
+            for (String element : environment) {
+                log("Setting environment variable: " + element,
                     Project.MSG_VERBOSE);
             }
         }
@@ -852,7 +941,7 @@ public class Java extends Task {
     private void setupWorkingDir(Execute exe) {
         if (dir == null) {
             dir = getProject().getBaseDir();
-        } else if (!dir.exists() || !dir.isDirectory()) {
+        } else if (!dir.isDirectory()) {
             throw new BuildException(dir.getAbsolutePath()
                                      + " is not a valid directory",
                                      getLocation());
@@ -900,10 +989,7 @@ public class Java extends Task {
     protected void run(String classname, Vector<String> args) throws BuildException {
         CommandlineJava cmdj = new CommandlineJava();
         cmdj.setClassname(classname);
-        final int size = args.size();
-        for (int i = 0; i < size; i++) {
-            cmdj.createArgument().setValue(args.elementAt(i));
-        }
+        args.forEach(arg -> cmdj.createArgument().setValue(arg));
         run(cmdj);
     }
 
@@ -927,7 +1013,7 @@ public class Java extends Task {
         if (timeout == null) {
             return null;
         }
-        return new ExecuteWatchdog(timeout.longValue());
+        return new ExecuteWatchdog(timeout);
     }
 
     /**
@@ -936,11 +1022,7 @@ public class Java extends Task {
      * @since 1.6.2
      */
     private void log(Throwable t) {
-        StringWriter sw = new StringWriter();
-        PrintWriter w = new PrintWriter(sw);
-        t.printStackTrace(w);
-        w.close();
-        log(sw.toString(), Project.MSG_ERR);
+        log(StringUtils.getStackTrace(t), Project.MSG_ERR);
     }
 
     /**
@@ -962,4 +1044,6 @@ public class Java extends Task {
     public CommandlineJava.SysProperties getSysProperties() {
         return getCommandLine().getSystemProperties();
     }
+
+
 }
