@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,6 +21,7 @@ package org.apache.tools.ant.taskdefs;
 import java.io.File;
 import java.io.IOException;
 import java.io.OutputStream;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -86,15 +87,15 @@ public class Javac extends MatchingTask {
 
     private static final String JAVAC10_PLUS = "javac10+";
     private static final String JAVAC9 = "javac9";
-    private static final String JAVAC19 = "javac1.9";
-    private static final String JAVAC18 = "javac1.8";
-    private static final String JAVAC17 = "javac1.7";
-    private static final String JAVAC16 = "javac1.6";
-    private static final String JAVAC15 = "javac1.5";
-    private static final String JAVAC14 = "javac1.4";
-    private static final String JAVAC13 = "javac1.3";
-    private static final String JAVAC12 = "javac1.2";
-    private static final String JAVAC11 = "javac1.1";
+    private static final String JAVAC9_ALIAS = "javac1.9";
+    private static final String JAVAC1_8 = "javac1.8";
+    private static final String JAVAC1_7 = "javac1.7";
+    private static final String JAVAC1_6 = "javac1.6";
+    private static final String JAVAC1_5 = "javac1.5";
+    private static final String JAVAC1_4 = "javac1.4";
+    private static final String JAVAC1_3 = "javac1.3";
+    private static final String JAVAC1_2 = "javac1.2";
+    private static final String JAVAC1_1 = "javac1.1";
     private static final String MODERN = "modern";
     private static final String CLASSIC = "classic";
     private static final String EXTJAVAC = "extJavac";
@@ -159,28 +160,16 @@ public class Javac extends MatchingTask {
     }
 
     private String assumedJavaVersion() {
-        if (JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_1_4)) {
-            return JAVAC14;
-        }
-        if (JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_1_5)) {
-            return JAVAC15;
-        }
-        if (JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_1_6)) {
-            return JAVAC16;
-        }
-        if (JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_1_7)) {
-            return JAVAC17;
-        }
         if (JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_1_8)) {
-            return JAVAC18;
-        }
-        if (JavaEnvUtils.isAtLeastJavaVersion("10")) {
-            return JAVAC10_PLUS;
+            return JAVAC1_8;
         }
         if (JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_9)) {
             return JAVAC9;
         }
-        return CLASSIC;
+        if (JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_10)) {
+            return JAVAC10_PLUS;
+        }
+        return MODERN; // as we are assumed to be 1.8+ and classic refers to the really old ones,  default to modern
     }
 
     /**
@@ -826,7 +815,7 @@ public class Javac extends MatchingTask {
      * @param include if true, includes Ant's own classpath in the classpath
      */
     public void setIncludeantruntime(final boolean include) {
-        includeAntRuntime = Boolean.valueOf(include);
+        includeAntRuntime = include;
     }
 
     /**
@@ -834,7 +823,7 @@ public class Javac extends MatchingTask {
      * @return whether or not the ant classpath is to be included in the classpath
      */
     public boolean getIncludeantruntime() {
-        return includeAntRuntime != null ? includeAntRuntime.booleanValue() : true;
+        return includeAntRuntime == null || includeAntRuntime;
     }
 
     /**
@@ -970,29 +959,24 @@ public class Javac extends MatchingTask {
     private String getAltCompilerName(final String anImplementation) {
         if (JAVAC10_PLUS.equalsIgnoreCase(anImplementation)
                 || JAVAC9.equalsIgnoreCase(anImplementation)
-                || JAVAC19.equalsIgnoreCase(anImplementation)
-                || JAVAC18.equalsIgnoreCase(anImplementation)
-                || JAVAC17.equalsIgnoreCase(anImplementation)
-                || JAVAC16.equalsIgnoreCase(anImplementation)
-                || JAVAC15.equalsIgnoreCase(anImplementation)
-                || JAVAC14.equalsIgnoreCase(anImplementation)
-                || JAVAC13.equalsIgnoreCase(anImplementation)) {
+                || JAVAC9_ALIAS.equalsIgnoreCase(anImplementation)
+                || JAVAC1_8.equalsIgnoreCase(anImplementation)
+                || JAVAC1_7.equalsIgnoreCase(anImplementation)
+                || JAVAC1_6.equalsIgnoreCase(anImplementation)
+                || JAVAC1_5.equalsIgnoreCase(anImplementation)
+                || JAVAC1_4.equalsIgnoreCase(anImplementation)
+                || JAVAC1_3.equalsIgnoreCase(anImplementation)) {
             return MODERN;
         }
-        if (JAVAC12.equalsIgnoreCase(anImplementation)
-                || JAVAC11.equalsIgnoreCase(anImplementation)) {
+        if (JAVAC1_2.equalsIgnoreCase(anImplementation)
+                || JAVAC1_1.equalsIgnoreCase(anImplementation)) {
             return CLASSIC;
         }
         if (MODERN.equalsIgnoreCase(anImplementation)) {
             final String nextSelected = assumedJavaVersion();
             if (JAVAC10_PLUS.equalsIgnoreCase(anImplementation)
                     || JAVAC9.equalsIgnoreCase(nextSelected)
-                    || JAVAC18.equalsIgnoreCase(nextSelected)
-                    || JAVAC17.equalsIgnoreCase(nextSelected)
-                    || JAVAC16.equalsIgnoreCase(nextSelected)
-                    || JAVAC15.equalsIgnoreCase(nextSelected)
-                    || JAVAC14.equalsIgnoreCase(nextSelected)
-                    || JAVAC13.equalsIgnoreCase(nextSelected)) {
+                    || JAVAC1_8.equalsIgnoreCase(nextSelected)) {
                 return nextSelected;
             }
         }
@@ -1156,9 +1140,8 @@ public class Javac extends MatchingTask {
      */
     protected void scanDir(final File srcDir, final File destDir, final String[] files) {
         final GlobPatternMapper m = new GlobPatternMapper();
-        final String[] extensions = findSupportedFileExtensions();
 
-        for (String extension : extensions) {
+        for (String extension : findSupportedFileExtensions()) {
             m.setFrom(extension);
             m.setTo("*.class");
             final SourceFileScanner sfs = new SourceFileScanner(this);
@@ -1178,9 +1161,8 @@ public class Javac extends MatchingTask {
     }
 
     private void collectFileListFromSourcePath() {
-        final String[] list = src.list();
-        for (int i = 0; i < list.length; i++) {
-            final File srcDir = getProject().resolveFile(list[i]);
+        for (String filename : src.list()) {
+            final File srcDir = getProject().resolveFile(filename);
             if (!srcDir.exists()) {
                 throw new BuildException("srcdir \""
                                          + srcDir.getPath()
@@ -1188,9 +1170,8 @@ public class Javac extends MatchingTask {
             }
 
             final DirectoryScanner ds = this.getDirectoryScanner(srcDir);
-            final String[] files = ds.getIncludedFiles();
 
-            scanDir(srcDir, destDir != null ? destDir : srcDir, files);
+            scanDir(srcDir, destDir != null ? destDir : srcDir, ds.getIncludedFiles());
         }
     }
 
@@ -1265,14 +1246,14 @@ public class Javac extends MatchingTask {
             || CLASSIC.equals(compilerImpl)
             || JAVAC10_PLUS.equals(compilerImpl)
             || JAVAC9.equals(compilerImpl)
-            || JAVAC18.equals(compilerImpl)
-            || JAVAC17.equals(compilerImpl)
-            || JAVAC16.equals(compilerImpl)
-            || JAVAC15.equals(compilerImpl)
-            || JAVAC14.equals(compilerImpl)
-            || JAVAC13.equals(compilerImpl)
-            || JAVAC12.equals(compilerImpl)
-            || JAVAC11.equals(compilerImpl);
+            || JAVAC1_8.equals(compilerImpl)
+            || JAVAC1_7.equals(compilerImpl)
+            || JAVAC1_6.equals(compilerImpl)
+            || JAVAC1_5.equals(compilerImpl)
+            || JAVAC1_4.equals(compilerImpl)
+            || JAVAC1_3.equals(compilerImpl)
+            || JAVAC1_2.equals(compilerImpl)
+            || JAVAC1_1.equals(compilerImpl);
     }
 
     /**
@@ -1453,15 +1434,15 @@ public class Javac extends MatchingTask {
             if (!"package-info.java".equals(f.getName())) {
                 continue;
             }
-            final String path = FILE_UTILS.removeLeadingPath(srcDir, f).
-                    replace(File.separatorChar, '/');
+            final String path = FILE_UTILS.removeLeadingPath(srcDir, f)
+                    .replace(File.separatorChar, '/');
             final String suffix = "/package-info.java";
             if (!path.endsWith(suffix)) {
                 log("anomalous package-info.java path: " + path, Project.MSG_WARN);
                 continue;
             }
             final String pkg = path.substring(0, path.length() - suffix.length());
-            packageInfos.put(pkg, Long.valueOf(f.lastModified()));
+            packageInfos.put(pkg, f.lastModified());
         }
     }
 
@@ -1477,13 +1458,13 @@ public class Javac extends MatchingTask {
             final File pkgBinDir = new File(dest, pkg.replace('/', File.separatorChar));
             pkgBinDir.mkdirs();
             final File pkgInfoClass = new File(pkgBinDir, "package-info.class");
-            if (pkgInfoClass.isFile() && pkgInfoClass.lastModified() >= sourceLastMod.longValue()) {
+            if (pkgInfoClass.isFile() && pkgInfoClass.lastModified() >= sourceLastMod) {
                 continue;
             }
             log("Creating empty " + pkgInfoClass);
             try (OutputStream os = Files.newOutputStream(pkgInfoClass.toPath())) {
                 os.write(PACKAGE_INFO_CLASS_HEADER);
-                final byte[] name = pkg.getBytes("UTF-8");
+                final byte[] name = pkg.getBytes(StandardCharsets.UTF_8);
                 final int length = name.length + /* "/package-info" */ 13;
                 os.write((byte) length / 256);
                 os.write((byte) length % 256);
@@ -1511,10 +1492,10 @@ public class Javac extends MatchingTask {
      * @return a mapping from module name to module source roots
      * @since 1.9.7
      */
-    private static Map<String,Collection<File>> resolveModuleSourcePathElement(
+    private static Map<String, Collection<File>> resolveModuleSourcePathElement(
             final File projectDir,
             final String element) {
-        final Map<String,Collection<File>> result = new TreeMap<String, Collection<File>>();
+        final Map<String, Collection<File>> result = new TreeMap<>();
         for (CharSequence resolvedElement : expandGroups(element)) {
             findModules(projectDir, resolvedElement.toString(), result);
         }
@@ -1548,7 +1529,7 @@ public class Javac extends MatchingTask {
                                 element,
                                 i));
                     }
-                    final Collection<? extends CharSequence> parts = resolveGroup(element.subSequence(i+1, end));
+                    final Collection<? extends CharSequence> parts = resolveGroup(element.subSequence(i + 1, end));
                     switch (parts.size()) {
                         case 0:
                             break;
@@ -1646,7 +1627,7 @@ public class Javac extends MatchingTask {
     private static void findModules(
             final File root,
             String pattern,
-            final Map<String,Collection<File>> collector) {
+            final Map<String, Collection<File>> collector) {
         pattern = pattern
                 .replace('/', File.separatorChar)
                 .replace('\\', File.separatorChar);
@@ -1687,21 +1668,15 @@ public class Javac extends MatchingTask {
         final String pathToModule,
         final String pathInModule,
         final Map<String,Collection<File>> collector) {
-        final FileUtils fu = FileUtils.getFileUtils();
-        final File f = fu.resolveFile(root, pathToModule);
+        final File f = FileUtils.getFileUtils().resolveFile(root, pathToModule);
         if (!f.isDirectory()) {
             return;
         }
         for (File module : f.listFiles(File::isDirectory)) {
             final String moduleName = module.getName();
-            final File moduleSourceRoot = pathInModule == null ?
-                    module :
-                    new File(module, pathInModule);
-            Collection<File> moduleRoots = collector.get(moduleName);
-            if (moduleRoots == null) {
-                moduleRoots = new ArrayList<>();
-                collector.put(moduleName, moduleRoots);
-            }
+            final File moduleSourceRoot = pathInModule == null
+                    ? module : new File(module, pathInModule);
+            Collection<File> moduleRoots = collector.computeIfAbsent(moduleName, k -> new ArrayList<>());
             moduleRoots.add(moduleSourceRoot);
         }
     }
