@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -133,12 +133,12 @@ public class JikesOutputParser implements ExecuteStreamHandler {
 
         while ((line = reader.readLine()) != null) {
             lower = line.toLowerCase();
-            if (line.trim().equals("")) {
+            if (line.trim().isEmpty()) {
                 continue;
             }
-            if (lower.indexOf("error") != -1) {
+            if (lower.contains("error")) {
                 setError(true);
-            } else if (lower.indexOf("warning") != -1) {
+            } else if (lower.contains("warning")) {
                 setError(false);
                    } else {
                 // If we don't know the type of the line
