@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -54,8 +54,8 @@ public class Javac13 extends DefaultCompilerAdapter {
             Class<?> c = Class.forName("com.sun.tools.javac.Main");
             Object compiler = c.newInstance();
             Method compile = c.getMethod("compile", String[].class);
-            int result = ((Integer) compile.invoke(compiler,
-                (Object) cmd.getArguments())).intValue();
+            int result = (Integer) compile.invoke(compiler,
+                    (Object) cmd.getArguments());
             return result == MODERN_COMPILER_SUCCESS;
         } catch (Exception ex) {
             if (ex instanceof BuildException) {
