@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,14 +24,15 @@ import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.StringTokenizer;
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.AbstractCvsTask;
-import org.apache.tools.ant.util.CollectionUtils;
 import org.apache.tools.ant.util.DOMElementWriter;
 import org.apache.tools.ant.util.DOMUtils;
 import org.apache.tools.ant.util.FileUtils;
@@ -403,7 +404,7 @@ public class CvsTagDiff extends AbstractCvsTask {
      */
     private void writeTagDiff(CvsTagEntry[] entries) throws BuildException {
         try (PrintWriter writer = new PrintWriter(new OutputStreamWriter(
-            Files.newOutputStream(mydestfile.toPath()), "UTF-8"))) {
+            Files.newOutputStream(mydestfile.toPath()), StandardCharsets.UTF_8))) {
             writer.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
             Document doc = DOMUtils.newDocument();
             Element root = doc.createElement("tagdiff");
@@ -420,18 +421,17 @@ public class CvsTagDiff extends AbstractCvsTask {
 
             root.setAttribute("cvsroot", getCvsRoot());
             root.setAttribute("package",
-                              CollectionUtils.flattenToString(packageNames));
+                    String.join(",", packageNames));
             DOM_WRITER.openElement(root, writer, 0, "\t");
             writer.println();
-            for (int i = 0, c = entries.length; i < c; i++) {
-                writeTagEntry(doc, writer, entries[i]);
+            for (CvsTagEntry entry : entries) {
+                writeTagEntry(doc, writer, entry);
             }
             DOM_WRITER.closeElement(root, writer, 0, "\t", true);
             writer.flush();
             if (writer.checkError()) {
                 throw new IOException("Encountered an error writing tagdiff");
             }
-            writer.close();
         } catch (UnsupportedEncodingException uee) {
             log(uee.toString(), Project.MSG_ERR);
         } catch (IOException ioe) {
