@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -365,7 +365,7 @@ public class ReplaceRegExp extends Task {
                     log("Replacing pattern '" + regex.getPattern(getProject())
                         + "' with '" + subs.getExpression(getProject())
                         + "' in '" + f.getPath() + "'" + (byline ? " by line" : "")
-                        + (flags.length() > 0 ? " with flags: '" + flags + "'" : "")
+                        + (flags.isEmpty() ? "" : " with flags: '" + flags + "'")
                         + ".", Project.MSG_VERBOSE);
 
                     if (byline) {
@@ -404,7 +404,7 @@ public class ReplaceRegExp extends Task {
 
                                 linebuf = new StringBuilder();
                             } else { // any other char
-                                if ((hasCR) || (c < 0)) {
+                                if (hasCR || c < 0) {
                                     // Mac-style linebreak or EOF (or both)
                                     changes |= replaceAndWrite(linebuf.toString(),
                                                                w, options);
