@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -1203,28 +1203,18 @@ public class JUnitTestRunner implements TestListener, JUnitTaskMirror.JUnitTestR
     private static void registerNonCrash()
             throws IOException {
         if (crashFile != null) {
-            FileWriter out = null;
-            try {
-                out = new FileWriter(crashFile);
+            try (FileWriter out = new FileWriter(crashFile)) {
                 out.write(Constants.TERMINATED_SUCCESSFULLY + "\n");
                 out.flush();
-            } finally {
-                FileUtils.close(out);
             }
         }
     }
 
     private static void registerTestCase(final String testCase) {
         if (crashFile != null) {
-            try {
-                FileWriter out = null;
-                try {
-                    out = new FileWriter(crashFile);
-                    out.write(testCase + "\n");
-                    out.flush();
-                } finally {
-                    FileUtils.close(out);
-                }
+            try (FileWriter out = new FileWriter(crashFile)) {
+                out.write(testCase + "\n");
+                out.flush();
             } catch (final IOException e) {
                 // ignored.
             }
