@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@
 
 package org.apache.tools.ant.taskdefs.optional.junitlauncher;
 
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.MagicNames;
 import org.apache.tools.ant.Project;
@@ -34,6 +35,7 @@ import org.junit.platform.engine.discovery.DiscoverySelectors;
 import org.junit.platform.launcher.EngineFilter;
 import org.junit.platform.launcher.Launcher;
 import org.junit.platform.launcher.LauncherDiscoveryRequest;
+import org.junit.platform.launcher.TagFilter;
 import org.junit.platform.launcher.TestExecutionListener;
 import org.junit.platform.launcher.TestPlan;
 import org.junit.platform.launcher.core.LauncherDiscoveryRequestBuilder;
@@ -302,7 +304,7 @@ public class LauncherSupport {
             // print the summary to System.out
             summary.printTo(new PrintWriter(System.out, true));
         }
-        final boolean hasTestFailures = summary.getTestsFailedCount() != 0;
+        final boolean hasTestFailures = summary.getTotalFailureCount() != 0;
         if (hasTestFailures) {
             // keep track of the test failure(s) for the entire launched instance
             this.testsFailed = true;
@@ -463,6 +465,13 @@ public class LauncherSupport {
         if (enginesToExclude != null && enginesToExclude.length > 0) {
             requestBuilder.filters(EngineFilter.excludeEngines(enginesToExclude));
         }
+        // add any tag filters
+        if (this.launchDefinition.getIncludeTags().size() > 0) {
+            requestBuilder.filters(TagFilter.includeTags(this.launchDefinition.getIncludeTags()));
+        }
+        if (this.launchDefinition.getExcludeTags().size() > 0) {
+            requestBuilder.filters(TagFilter.excludeTags(this.launchDefinition.getExcludeTags()));
+        }
     }
 
     private enum StreamType {
