@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,7 +23,6 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import org.apache.tools.ant.BuildException;
@@ -551,7 +550,7 @@ public class Scp extends SSHBase {
 
     private BuildException exactlyOne(final String[] attrs, final String alt) {
         return new BuildException("Exactly one of [%s]%s is required",
-            Stream.of(attrs).collect(Collectors.joining("|")),
+                String.join("|", attrs),
             alt == null ? "" : " or " + alt);
     }
 }
