@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -55,7 +55,7 @@ public final class AntFilterReader extends DataType {
      */
     public String getClassName() {
         if (isReference()) {
-            return ((AntFilterReader) getCheckedRef()).getClassName();
+            return getRef().getClassName();
         }
         dieOnCircularReference();
         return className;
@@ -110,7 +110,7 @@ public final class AntFilterReader extends DataType {
      */
     public Path getClasspath() {
         if (isReference()) {
-            ((AntFilterReader) getCheckedRef()).getClasspath();
+            getRef().getClasspath();
         }
         dieOnCircularReference();
         return classpath;
@@ -135,7 +135,7 @@ public final class AntFilterReader extends DataType {
      */
     public Parameter[] getParams() {
         if (isReference()) {
-            ((AntFilterReader) getCheckedRef()).getParams();
+            getRef().getParams();
         }
         dieOnCircularReference();
         return parameters.toArray(new Parameter[parameters.size()]);
@@ -173,4 +173,8 @@ public final class AntFilterReader extends DataType {
             setChecked(true);
         }
     }
+
+    private AntFilterReader getRef() {
+        return getCheckedRef(AntFilterReader.class);
+    }
 }
