@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -25,28 +25,28 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.StringTokenizer;
+import java.util.stream.Stream;
 
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.ProjectComponent;
 import org.apache.tools.ant.taskdefs.condition.Os;
-import org.apache.tools.ant.util.StringUtils;
 
 /**
  * Commandline objects help handling command lines specifying processes to
  * execute.
- *
+ * <p>
  * The class can be used to define a command line as nested elements or as a
  * helper to define a command line by an application.
- * <p>
- * <code>
- * &lt;someelement&gt;<br>
- * &nbsp;&nbsp;&lt;acommandline executable="/executable/to/run"&gt;<br>
- * &nbsp;&nbsp;&nbsp;&nbsp;&lt;argument value="argument 1" /&gt;<br>
- * &nbsp;&nbsp;&nbsp;&nbsp;&lt;argument line="argument_1 argument_2 argument_3" /&gt;<br>
- * &nbsp;&nbsp;&nbsp;&nbsp;&lt;argument value="argument 4" /&gt;<br>
- * &nbsp;&nbsp;&lt;/acommandline&gt;<br>
- * &lt;/someelement&gt;<br>
- * </code>
+ * </p>
+ * <pre>
+ * &lt;someelement&gt;
+ *   &lt;acommandline executable="/executable/to/run"&gt;
+ *     &lt;argument value="argument 1"/&gt;
+ *     &lt;argument line="argument_1 argument_2 argument_3"/&gt;
+ *     &lt;argument value="argument 4"/&gt;
+ *   &lt;/acommandline&gt;
+ * &lt;/someelement&gt;
+ * </pre>
  * The element <code>someelement</code> must provide a method
  * <code>createAcommandline</code> which returns an instance of this class.
  *
@@ -58,19 +58,15 @@ public class Commandline implements Cloneable {
     /**
      * The arguments of the command
      */
-    private List<Argument> arguments = new ArrayList<Argument>();
+    private List<Argument> arguments = new ArrayList<>();
 
     /**
      * the program to execute
      */
     private String executable = null;
 
-    protected static final String DISCLAIMER =
-        StringUtils.LINE_SEP
-        + "The \' characters around the executable and arguments are"
-        + StringUtils.LINE_SEP
-        + "not part of the command."
-        + StringUtils.LINE_SEP;
+    protected static final String DISCLAIMER = String.format(
+            "%nThe ' characters around the executable and arguments are%nnot part of the command.%n");
 
     /**
      * Create a command line from a string.
@@ -182,13 +178,25 @@ public class Commandline implements Cloneable {
             this.suffix = suffix != null ? suffix : "";
         }
 
+        /**
+         * Copies settings from a different argument.
+         *
+         * @param other the argument to copy setting from
+         *
+         * @since Ant 1.10.6
+         */
+        public void copyFrom(Argument other) {
+            this.parts = other.parts;
+            this.prefix = other.prefix;
+            this.suffix = other.suffix;
+        }
+
         /**
          * Return the constituent parts of this Argument.
          * @return an array of strings.
          */
         public String[] getParts() {
-            if (parts == null || parts.length == 0
-                || (prefix.length() == 0 && suffix.length() == 0)) {
+            if (parts == null || parts.length == 0 || (prefix.isEmpty() && suffix.isEmpty())) {
                 return parts;
             }
             String[] fullParts = new String[parts.length];
@@ -229,11 +237,9 @@ public class Commandline implements Cloneable {
          */
         public int getPosition() {
             if (realPos == -1) {
-                realPos = (executable == null ? 0 : 1);
-                for (int i = 0; i < position; i++) {
-                    Argument arg = (Argument) arguments.get(i);
-                    realPos += arg.getParts().length;
-                }
+                realPos = (executable == null ? 0 : 1)
+                        + (int) arguments.stream().limit(position)
+                        .map(Argument::getParts).flatMap(Stream::of).count();
             }
             return realPos;
         }
@@ -251,6 +257,7 @@ public class Commandline implements Cloneable {
         /**
          * Get the prefix to be placed in front of the inserted argument.
          *
+         * @return String
          * @since Ant 1.8.0
          */
         public String getPrefix() {
@@ -270,6 +277,7 @@ public class Commandline implements Cloneable {
         /**
          * Get the suffix to be placed at the end of the inserted argument.
          *
+         * @return String
          * @since Ant 1.8.0
          */
         public String getSuffix() {
@@ -318,11 +326,25 @@ public class Commandline implements Cloneable {
      * @param executable the String executable name.
      */
     public void setExecutable(String executable) {
-        if (executable == null || executable.length() == 0) {
+        setExecutable(executable, true);
+    }
+
+    /**
+     * Set the executable to run.
+     *
+     * @param executable the String executable name.
+     * @param translateFileSeparator if {@code true} all file separators in the string
+     * are converted to the platform specific value.
+     *
+     * @since Ant 1.9.7
+     */
+    public void setExecutable(String executable, boolean translateFileSeparator) {
+        if (executable == null || executable.isEmpty()) {
             return;
         }
-        this.executable = executable.replace('/', File.separatorChar)
-            .replace('\\', File.separatorChar);
+        this.executable = translateFileSeparator
+            ? executable.replace('/', File.separatorChar).replace('\\', File.separatorChar)
+            : executable;
     }
 
     /**
@@ -338,8 +360,8 @@ public class Commandline implements Cloneable {
      * @param line an array of arguments to append.
      */
     public void addArguments(String[] line) {
-        for (int i = 0; i < line.length; i++) {
-            createArgument().setValue(line[i]);
+        for (String l : line) {
+            createArgument().setValue(l);
         }
     }
 
@@ -348,7 +370,7 @@ public class Commandline implements Cloneable {
      * @return the commandline as an array of strings.
      */
     public String[] getCommandline() {
-        final List<String> commands = new LinkedList<String>();
+        final List<String> commands = new LinkedList<>();
         addCommandToList(commands.listIterator());
         return commands.toArray(new String[commands.size()]);
     }
@@ -371,7 +393,7 @@ public class Commandline implements Cloneable {
      * @return the arguments as an array of strings.
      */
     public String[] getArguments() {
-        List<String> result = new ArrayList<String>(arguments.size() * 2);
+        List<String> result = new ArrayList<>(arguments.size() * 2);
         addArgumentsToList(result.listIterator());
         return result.toArray(new String[result.size()]);
     }
@@ -382,13 +404,11 @@ public class Commandline implements Cloneable {
      * @since Ant 1.6
      */
     public void addArgumentsToList(ListIterator<String> list) {
-        final int size = arguments.size();
-        for (int i = 0; i < size; i++) {
-            Argument arg = arguments.get(i);
+        for (Argument arg : arguments) {
             String[] s = arg.getParts();
             if (s != null) {
-                for (int j = 0; j < s.length; j++) {
-                    list.add(s[j]);
+                for (String value : s) {
+                    list.add(value);
                 }
             }
         }
@@ -398,6 +418,7 @@ public class Commandline implements Cloneable {
      * Return the command line as a string.
      * @return the command line.
      */
+    @Override
     public String toString() {
         return toString(getCommandline());
     }
@@ -414,21 +435,19 @@ public class Commandline implements Cloneable {
      *                           and double quotes.
      */
     public static String quoteArgument(String argument) {
-        if (argument.indexOf("\"") > -1) {
-            if (argument.indexOf("\'") > -1) {
+        if (argument.contains("\"")) {
+            if (argument.contains("\'")) {
                 throw new BuildException("Can\'t handle single and double"
                         + " quotes in same argument");
-            } else {
-                return '\'' + argument + '\'';
             }
-        } else if (argument.indexOf("\'") > -1
-                   || argument.indexOf(" ") > -1
-                   // WIN9x uses a bat file for executing commands
-                   || (IS_WIN_9X && argument.indexOf(';') != -1)) {
-            return '\"' + argument + '\"';
-        } else {
-            return argument;
+            return '\'' + argument + '\'';
         }
+        if (argument.contains("\'") || argument.contains(" ")
+                // WIN9x uses a bat file for executing commands
+                || (IS_WIN_9X && argument.contains(";"))) {
+            return '\"' + argument + '\"';
+        }
+        return argument;
     }
 
     /**
@@ -445,11 +464,11 @@ public class Commandline implements Cloneable {
         }
         // path containing one or more elements
         final StringBuilder result = new StringBuilder();
-        for (int i = 0; i < line.length; i++) {
-            if (i > 0) {
+        for (String l : line) {
+            if (result.length() > 0) {
                 result.append(' ');
             }
-            result.append(quoteArgument(line[i]));
+            result.append(quoteArgument(l));
         }
         return result.toString();
     }
@@ -461,7 +480,7 @@ public class Commandline implements Cloneable {
      * An empty or null toProcess parameter results in a zero sized array.
      */
     public static String[] translateCommandline(String toProcess) {
-        if (toProcess == null || toProcess.length() == 0) {
+        if (toProcess == null || toProcess.isEmpty()) {
             //no command? no string
             return new String[0];
         }
@@ -472,7 +491,7 @@ public class Commandline implements Cloneable {
         final int inDoubleQuote = 2;
         int state = normal;
         final StringTokenizer tok = new StringTokenizer(toProcess, "\"\' ", true);
-        final ArrayList<String> result = new ArrayList<String>();
+        final ArrayList<String> result = new ArrayList<>();
         final StringBuilder current = new StringBuilder();
         boolean lastTokenHasBeenQuoted = false;
 
@@ -501,7 +520,7 @@ public class Commandline implements Cloneable {
                 } else if ("\"".equals(nextTok)) {
                     state = inDoubleQuote;
                 } else if (" ".equals(nextTok)) {
-                    if (lastTokenHasBeenQuoted || current.length() != 0) {
+                    if (lastTokenHasBeenQuoted || current.length() > 0) {
                         result.add(current.toString());
                         current.setLength(0);
                     }
@@ -512,7 +531,7 @@ public class Commandline implements Cloneable {
                 break;
             }
         }
-        if (lastTokenHasBeenQuoted || current.length() != 0) {
+        if (lastTokenHasBeenQuoted || current.length() > 0) {
             result.add(current.toString());
         }
         if (state == inQuote || state == inDoubleQuote) {
@@ -534,10 +553,11 @@ public class Commandline implements Cloneable {
      * Generate a deep clone of the contained object.
      * @return a clone of the contained object
      */
+    @Override
     public Object clone() {
         try {
             Commandline c = (Commandline) super.clone();
-            c.arguments = new ArrayList<Argument>(arguments);
+            c.arguments = new ArrayList<>(arguments);
             return c;
         } catch (CloneNotSupportedException e) {
             throw new BuildException(e);
@@ -574,7 +594,7 @@ public class Commandline implements Cloneable {
 
     /**
      * Return a String that describes the command and arguments suitable for
-     * verbose output before a call to <code>Runtime.exec(String[])<code>.
+     * verbose output before a call to <code>Runtime.exec(String[])</code>.
      * @return a string that describes the command and arguments.
      * @since Ant 1.5
      */
@@ -584,7 +604,7 @@ public class Commandline implements Cloneable {
 
     /**
      * Return a String that describes the arguments suitable for
-     * verbose output before a call to <code>Runtime.exec(String[])<code>.
+     * verbose output before a call to <code>Runtime.exec(String[])</code>.
      * @return a string that describes the arguments.
      * @since Ant 1.5
      */
@@ -594,7 +614,7 @@ public class Commandline implements Cloneable {
 
     /**
      * Return a String that describes the command and arguments suitable for
-     * verbose output before a call to <code>Runtime.exec(String[])<code>.
+     * verbose output before a call to <code>Runtime.exec(String[])</code>.
      * @param line the Commandline to describe.
      * @return a string that describes the command and arguments.
      * @since Ant 1.5
@@ -605,7 +625,7 @@ public class Commandline implements Cloneable {
 
     /**
      * Return a String that describes the arguments suitable for
-     * verbose output before a call to <code>Runtime.exec(String[])<code>.
+     * verbose output before a call to <code>Runtime.exec(String[])</code>.
      * @param line the Commandline whose arguments to describe.
      * @return a string that describes the arguments.
      * @since Ant 1.5
@@ -616,7 +636,7 @@ public class Commandline implements Cloneable {
 
     /**
      * Return a String that describes the command and arguments suitable for
-     * verbose output before a call to <code>Runtime.exec(String[])<code>.
+     * verbose output before a call to <code>Runtime.exec(String[])</code>.
      *
      * <p>This method assumes that the first entry in the array is the
      * executable to run.</p>
@@ -628,9 +648,7 @@ public class Commandline implements Cloneable {
         if (args == null || args.length == 0) {
             return "";
         }
-        StringBuffer buf = new StringBuffer("Executing \'");
-        buf.append(args[0]);
-        buf.append("\'");
+        StringBuilder buf = new StringBuilder("Executing \'").append(args[0]).append("\'");
         if (args.length > 1) {
             buf.append(" with ");
             buf.append(describeArguments(args, 1));
@@ -642,7 +660,7 @@ public class Commandline implements Cloneable {
 
     /**
      * Return a String that describes the arguments suitable for
-     * verbose output before a call to <code>Runtime.exec(String[])<code>.
+     * verbose output before a call to <code>Runtime.exec(String[])</code>.
      * @param args the command line to describe as an array of strings.
      * @return a string that describes the arguments.
      * @since Ant 1.5
@@ -653,7 +671,7 @@ public class Commandline implements Cloneable {
 
     /**
      * Return a String that describes the arguments suitable for
-     * verbose output before a call to <code>Runtime.exec(String[])<code>.
+     * verbose output before a call to <code>Runtime.exec(String[])</code>.
      *
      * @param args the command line to describe as an array of strings.
      * @param offset ignore entries before this index.
@@ -665,14 +683,10 @@ public class Commandline implements Cloneable {
         if (args == null || args.length <= offset) {
             return "";
         }
-        StringBuffer buf = new StringBuffer("argument");
-        if (args.length > offset) {
-            buf.append("s");
-        }
-        buf.append(":").append(StringUtils.LINE_SEP);
+        StringBuilder buf = new StringBuilder();
+        buf.append(String.format("argument%s:%n", args.length > offset ? "s" : ""));
         for (int i = offset; i < args.length; i++) {
-            buf.append("\'").append(args[i]).append("\'")
-                .append(StringUtils.LINE_SEP);
+            buf.append(String.format("\'%s\'%n", args[i]));
         }
         buf.append(DISCLAIMER);
         return buf.toString();
