@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -70,7 +70,7 @@ public class FileList extends DataType implements ResourceCollection {
      */
     @Override
     public void setRefid(Reference r) throws BuildException {
-        if ((dir != null) || (!filenames.isEmpty())) {
+        if (dir != null || !filenames.isEmpty()) {
             throw tooManyAttributes();
         }
         super.setRefid(r);
@@ -106,7 +106,7 @@ public class FileList extends DataType implements ResourceCollection {
      */
     public void setFiles(String filenames) {
         checkAttributesAllowed();
-        if (!(filenames == null || filenames.isEmpty())) {
+        if (filenames != null && !filenames.isEmpty()) {
             StringTokenizer tok = new StringTokenizer(
                 filenames, ", \t\n\r\f", false);
             while (tok.hasMoreTokens()) {
@@ -136,16 +136,6 @@ public class FileList extends DataType implements ResourceCollection {
         return filenames.toArray(new String[filenames.size()]);
     }
 
-    /**
-     * Performs the check for circular references and returns the
-     * referenced FileList.
-     * @param p the current project
-     * @return the FileList represented by a referenced filelist.
-     */
-    protected FileList getRef(Project p) {
-        return (FileList) getCheckedRef(p);
-    }
-
     /**
      * Inner class corresponding to the &lt;file&gt; nested element.
      */
@@ -191,7 +181,7 @@ public class FileList extends DataType implements ResourceCollection {
     @Override
     public Iterator<Resource> iterator() {
         if (isReference()) {
-            return getRef(getProject()).iterator();
+            return getRef().iterator();
         }
         return new FileResourceIterator(getProject(), dir,
             filenames.toArray(new String[filenames.size()]));
@@ -205,7 +195,7 @@ public class FileList extends DataType implements ResourceCollection {
     @Override
     public int size() {
         if (isReference()) {
-            return getRef(getProject()).size();
+            return getRef().size();
         }
         return filenames.size();
     }
@@ -220,4 +210,12 @@ public class FileList extends DataType implements ResourceCollection {
         return true;
     }
 
+    private FileList getRef() {
+        return getCheckedRef(FileList.class);
+    }
+
+    private FileList getRef(Project p) {
+        return getCheckedRef(FileList.class, getDataTypeName(), p);
+    }
+
 }
