@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -376,7 +376,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
      */
     public String[] list() {
         if (isReference()) {
-            return ((Path) getCheckedRef()).list();
+            return getRef().list();
         }
         return assertFilesystemOnly(union) == null
             ? new String[0] : union.list();
@@ -389,7 +389,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
      */
     @Override
     public String toString() {
-        return isReference() ? getCheckedRef().toString()
+        return isReference() ? getRef().toString()
             : union == null ? "" : union.toString();
     }
 
@@ -463,7 +463,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
     @Override
     public synchronized int size() {
         if (isReference()) {
-            return ((Path) getCheckedRef()).size();
+            return getRef().size();
         }
         dieOnCircularReference();
         return union == null ? 0 : assertFilesystemOnly(union).size();
@@ -595,7 +595,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
         if (JavaEnvUtils.isKaffe()) {
             // newer versions of Kaffe (1.1.1+) won't have this,
             // but this will be sorted by FileSet anyway.
-            File kaffeShare = new File(System.getProperty("java.home")
+            File kaffeShare = new File(JavaEnvUtils.getJavaHome()
                                        + File.separator + "share"
                                        + File.separator + "kaffe");
             if (kaffeShare.isDirectory()) {
@@ -612,57 +612,44 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
             // TODO is this code still necessary? is there any 1.2+ port?
             // Pull in *.zip from packages directory
             FileSet msZipFiles = new FileSet();
-            msZipFiles.setDir(new File(System.getProperty("java.home")
-                + File.separator + "Packages"));
+            msZipFiles.setDir(new File(JavaEnvUtils.getJavaHome()
+                    + File.separator + "Packages"));
             msZipFiles.setIncludes("*.ZIP");
             addFileset(msZipFiles);
         } else {
             // JDK 1.2+ seems to set java.home to the JRE directory.
-            addExisting(new Path(null,
-                                 System.getProperty("java.home")
-                                 + File.separator + "lib"
-                                 + File.separator + "rt.jar"));
+            addExisting(new Path(null, JavaEnvUtils.getJavaHome()
+                    + File.separator + "lib" + File.separator + "rt.jar"));
             // Just keep the old version as well and let addExisting
             // sort it out.
-            addExisting(new Path(null,
-                                 System.getProperty("java.home")
-                                 + File.separator + "jre"
-                                 + File.separator + "lib"
-                                 + File.separator + "rt.jar"));
+            addExisting(new Path(null, JavaEnvUtils.getJavaHome()
+                    + File.separator + "jre" + File.separator + "lib"
+                    + File.separator + "rt.jar"));
 
             // Sun's and Apple's 1.4 have JCE and JSSE in separate jars.
             for (String secJar : Arrays.asList("jce", "jsse")) {
-                addExisting(new Path(null,
-                        System.getProperty("java.home")
-                                + File.separator + "lib"
-                                + File.separator + secJar + ".jar"));
-                addExisting(new Path(null,
-                        System.getProperty("java.home")
-                                + File.separator + ".."
-                                + File.separator + "Classes"
-                                + File.separator + secJar + ".jar"));
+                addExisting(new Path(null, JavaEnvUtils.getJavaHome()
+                        + File.separator + "lib"
+                        + File.separator + secJar + ".jar"));
+                addExisting(new Path(null, JavaEnvUtils.getJavaHome()
+                        + File.separator + ".." + File.separator + "Classes"
+                        + File.separator + secJar + ".jar"));
             }
 
             // IBM's 1.4 has rt.jar split into 4 smaller jars and a combined
             // JCE/JSSE in security.jar.
             for (String ibmJar : Arrays.asList("core", "graphics", "security", "server", "xml")) {
-                addExisting(new Path(null,
-                        System.getProperty("java.home")
-                                + File.separator + "lib"
-                                + File.separator + ibmJar + ".jar"));
+                addExisting(new Path(null, JavaEnvUtils.getJavaHome()
+                        + File.separator + "lib" + File.separator + ibmJar + ".jar"));
             }
 
             // Added for MacOS X
-            addExisting(new Path(null,
-                                 System.getProperty("java.home")
-                                 + File.separator + ".."
-                                 + File.separator + "Classes"
-                                 + File.separator + "classes.jar"));
-            addExisting(new Path(null,
-                                 System.getProperty("java.home")
-                                 + File.separator + ".."
-                                 + File.separator + "Classes"
-                                 + File.separator + "ui.jar"));
+            addExisting(new Path(null, JavaEnvUtils.getJavaHome()
+                    + File.separator + ".." + File.separator + "Classes"
+                    + File.separator + "classes.jar"));
+            addExisting(new Path(null, JavaEnvUtils.getJavaHome()
+                    + File.separator + ".." + File.separator + "Classes"
+                    + File.separator + "ui.jar"));
         }
     }
 
@@ -703,7 +690,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
     @Override
     public final synchronized Iterator<Resource> iterator() {
         if (isReference()) {
-            return ((Path) getCheckedRef()).iterator();
+            return getRef().iterator();
         }
         dieOnCircularReference();
         if (getPreserveBC()) {
@@ -720,7 +707,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
     @Override
     public synchronized boolean isFilesystemOnly() {
         if (isReference()) {
-            return ((Path) getCheckedRef()).isFilesystemOnly();
+            return getRef().isFilesystemOnly();
         }
         dieOnCircularReference();
         assertFilesystemOnly(union);
@@ -777,4 +764,8 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
         return path != null && (path.contains("*") || path.contains("?"));
     }
 
+    private Path getRef() {
+        return getCheckedRef(Path.class);
+    }
+
 }
