@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -325,6 +325,8 @@ public class ModifiedSelector extends BaseExtendSelector
                 algorithm = new DigestAlgorithm();
             } else if ("checksum".equals(algoName.getValue())) {
                 algorithm = new ChecksumAlgorithm();
+            } else if ("lastmodified".equals(algoName.getValue())) {
+                algorithm = new LastModifiedAlgorithm();
             }
         } else if (algorithmClass != null) {
             // use Algorithm specified by classname
@@ -393,6 +395,7 @@ public class ModifiedSelector extends BaseExtendSelector
      * @param type the type to check against
      * @return a castable object
      */
+    @SuppressWarnings("unchecked")
     protected <T> T loadClass(String classname, String msg, Class<? extends T> type) {
         try {
             // load the specified class
@@ -485,7 +488,7 @@ public class ModifiedSelector extends BaseExtendSelector
      * @param basedir as described in BaseExtendSelector
      * @param filename as described in BaseExtendSelector
      * @param cacheKey the name for the key for storing the hashvalue
-     * @return <tt>true</tt> if the file is selected otherwise <tt>false</tt>
+     * @return <code>true</code> if the file is selected otherwise <code>false</code>
      */
     private boolean isSelected(File basedir, String filename, String cacheKey) {
         validate();
@@ -692,9 +695,7 @@ public class ModifiedSelector extends BaseExtendSelector
     @Override
     public void setParameters(Parameter... parameters) {
         if (parameters != null) {
-            for (Parameter p : parameters) {
-                configParameter.add(p);
-            }
+            Collections.addAll(configParameter, parameters);
         }
     }
 
@@ -776,14 +777,8 @@ public class ModifiedSelector extends BaseExtendSelector
      */
     @Override
     public String toString() {
-        StringBuilder buf = new StringBuilder("{modifiedselector");
-        buf.append(" update=").append(update);
-        buf.append(" seldirs=").append(selectDirectories);
-        buf.append(" cache=").append(cache);
-        buf.append(" algorithm=").append(algorithm);
-        buf.append(" comparator=").append(comparator);
-        buf.append("}");
-        return buf.toString();
+        return String.format("{modifiedselector update=%s seldirs=%s cache=%s algorithm=%s comparator=%s}",
+                update, selectDirectories, cache, algorithm, comparator);
     }
 
 
@@ -920,7 +915,7 @@ public class ModifiedSelector extends BaseExtendSelector
 
     /**
      * The enumerated type for algorithm.
-     * The values are "hashValue", "digest" and "checksum".
+     * The values are "hashValue", "digest", "checksum" and "lastmodified".
      */
     public static class AlgorithmName extends EnumeratedAttribute {
         /**
@@ -929,7 +924,7 @@ public class ModifiedSelector extends BaseExtendSelector
          */
         @Override
         public String[] getValues() {
-            return new String[] {"hashvalue", "digest", "checksum"};
+            return new String[] {"hashvalue", "digest", "checksum", "lastmodified"};
         }
     }
 
