@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -32,6 +32,7 @@ import java.net.URL;
 import java.net.URLConnection;
 import java.nio.channels.Channel;
 import java.nio.file.Files;
+import java.nio.file.NoSuchFileException;
 import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.nio.file.StandardOpenOption;
@@ -39,6 +40,8 @@ import java.text.DecimalFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Locale;
+import java.util.Optional;
 import java.util.Random;
 import java.util.Stack;
 import java.util.StringTokenizer;
@@ -858,7 +861,7 @@ public class FileUtils {
         if (isDirectory) {
             directory = new StringBuilder(path.substring(index).replace(File.separatorChar, '.'));
         } else {
-            int dirEnd = path.lastIndexOf(File.separatorChar, path.length());
+            int dirEnd = path.lastIndexOf(File.separatorChar);
             if (dirEnd == -1 || dirEnd < index) {
                 file = path.substring(index);
             } else {
@@ -1256,7 +1259,7 @@ public class FileUtils {
      *
      * <p>The coding of the output is the same as what File.toURI().toASCIIString() produces</p>
      *
-     * See <a href="http://www.w3.org/TR/xml11/#dt-sysid">dt-sysid</a>
+     * See <a href="https://www.w3.org/TR/xml11/#dt-sysid">dt-sysid</a>
      * which makes some mention of how
      * characters not supported by URI Reference syntax should be escaped.
      *
@@ -1769,4 +1772,63 @@ public class FileUtils {
             return Files.newOutputStream(path);
         }
     }
+
+    /**
+     * Tries to determine the case sensitivity of the filesystem corresponding to the
+     * {@code path}. While doing so, this method might create a temporary file under
+     * the directory represented by the {@code path}, if it's a directory or in the
+     * parent directory of the {@code path}, if it's a file.
+     * <p>
+     * This method works on a best effort basis and will return an {@link Optional#empty()}
+     * if it cannot determine the case sensitivity, either due to exception or for any other
+     * reason.
+     * </p>
+     * @param path The path whose filesystem case sensitivity needs to be checked
+     * @return Returns true if the filesystem corresponding to the passed {@code path}
+     *          is case sensitive. Else returns false. If the case sensitivity
+     *          cannot be determined for whatever reason, this method returns an
+     *          {@link Optional#empty()}
+     * @throws IllegalArgumentException If the passed path is null
+     * @since Ant 1.10.6
+     */
+    public static Optional<Boolean> isCaseSensitiveFileSystem(final Path path) {
+        if (path == null) {
+            throw new IllegalArgumentException("Path cannot be null");
+        }
+        final String mixedCaseFileNamePrefix = "aNt";
+        Path mixedCaseTmpFile = null;
+        boolean caseSensitive;
+        try {
+            if (Files.isRegularFile(path)) {
+                mixedCaseTmpFile = Files.createTempFile(path.getParent(), mixedCaseFileNamePrefix, null);
+            } else if (Files.isDirectory(path)) {
+                mixedCaseTmpFile = Files.createTempFile(path, mixedCaseFileNamePrefix, null);
+            } else {
+                // we can only do our tricks to figure out whether the filesystem is
+                // case sensitive, only if the path is a directory or a file.
+                // In other cases (like the path being non-existent), we don't
+                // have a way to determine that detail
+                return Optional.empty();
+            }
+            final Path lowerCasePath = Paths.get(mixedCaseTmpFile.toString().toLowerCase(Locale.US));
+            try {
+                caseSensitive = !Files.isSameFile(mixedCaseTmpFile, lowerCasePath);
+            } catch (NoSuchFileException nsfe) {
+                // a NSFE implies that the "lowerCasePath" file wasn't considered to be present
+                // even if the different cased file exists. That effectively means this is a
+                // case sensitive filesystem
+                caseSensitive = true;
+            }
+        } catch (IOException ioe) {
+            System.err.println("Could not determine the case sensitivity of the " +
+                    "filesystem for path " + path + " due to " + ioe);
+            return Optional.empty();
+        } finally {
+            // delete the tmp file
+            if (mixedCaseTmpFile != null) {
+                FileUtils.delete(mixedCaseTmpFile.toFile());
+            }
+        }
+        return Optional.of(caseSensitive);
+    }
 }
