@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -69,8 +69,10 @@ public class ResourceUtils {
     /**
      * Name of charset "ISO Latin Alphabet No. 1, a.k.a. ISO-LATIN-1".
      *
+     * @deprecated use StandardCharsets.ISO_8859_1
      * @since Ant 1.8.1
      */
+    @Deprecated
     public static final String ISO_8859_1 = "ISO-8859-1";
 
     private static final long MAX_IO_CHUNK_SIZE = 16 * 1024 * 1024L; // 16 MB
