@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -110,7 +110,7 @@ public class JavaxScriptRunner extends ScriptRunnerBase {
                             "Unable to create javax script engine for %s",
                             getLanguage());
                     }
-                    if (Compilable.class.isInstance(engine)) {
+                    if (engine instanceof Compilable) {
                         getProject().log("compile script " + execName,
                             Project.MSG_VERBOSE);
 
@@ -179,12 +179,10 @@ public class JavaxScriptRunner extends ScriptRunnerBase {
 
         if ("FX".equalsIgnoreCase(getLanguage())) {
             source = source.entrySet().stream()
-                .collect(Collectors.toMap(
-                    e -> String.format("%s:%s", e.getKey(),
-                        e.getValue().getClass().getName()),
-                    Map.Entry::getValue));
+                .collect(Collectors.toMap(e -> String.format("%s:%s", e.getKey(),
+                        e.getValue().getClass().getName()), Map.Entry::getValue));
         }
-        source.forEach(target::accept);
+        source.forEach(target);
     }
 
     private ScriptEngine createEngine() {
