@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,6 +19,8 @@
 package org.apache.tools.ant.taskdefs;
 
 import java.io.File;
+
+import org.apache.tools.ant.MagicNames;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.compilers.CompilerAdapter;
 import org.apache.tools.ant.taskdefs.compilers.CompilerAdapterFactory;
@@ -215,13 +217,13 @@ public class JavacTest {
 
     @Test
     public void testSourceWithDefault() {
-        project.setNewProperty("ant.build.javac.source", "1.4");
+        project.setNewProperty(MagicNames.BUILD_JAVAC_SOURCE, "1.4");
         assertEquals("1.4", javac.getSource());
     }
 
     @Test
     public void testSourceOverridesDefault() {
-        project.setNewProperty("ant.build.javac.source", "1.4");
+        project.setNewProperty(MagicNames.BUILD_JAVAC_SOURCE, "1.4");
         javac.setSource("1.5");
         assertEquals("1.5", javac.getSource());
     }
@@ -233,13 +235,13 @@ public class JavacTest {
 
     @Test
     public void testTargetWithDefault() {
-        project.setNewProperty("ant.build.javac.target", "1.4");
+        project.setNewProperty(MagicNames.BUILD_JAVAC_TARGET, "1.4");
         assertEquals("1.4", javac.getTarget());
     }
 
     @Test
     public void testTargetOverridesDefault() {
-        project.setNewProperty("ant.build.javac.target", "1.4");
+        project.setNewProperty(MagicNames.BUILD_JAVAC_TARGET, "1.4");
         javac.setTarget("1.5");
         assertEquals("1.5", javac.getTarget());
     }
