@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,6 +17,7 @@
  */
 package org.apache.tools.ant.util;
 
+import org.apache.tools.ant.MagicTestNames;
 import org.junit.Test;
 
 import java.io.ByteArrayOutputStream;
@@ -24,6 +25,7 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.InputStreamReader;
 import java.io.StringReader;
+import java.nio.charset.StandardCharsets;
 
 import static org.junit.Assert.assertEquals;
 
@@ -32,7 +34,7 @@ import static org.junit.Assert.assertEquals;
  */
 public class ReaderInputStreamTest {
 
-    private static final String ROOT = System.getProperty("root");
+    private static final String ROOT = System.getProperty(MagicTestNames.TEST_ROOT_DIRECTORY);
 
     @Test
     public void testSimple() throws Exception {
@@ -60,9 +62,9 @@ public class ReaderInputStreamTest {
             }
             bytes[pos++] = (byte) res;
         }
-        bytes = "abc".getBytes("utf-16");
+        bytes = "abc".getBytes(StandardCharsets.UTF_16);
         //        String n = new String(bytes, 0, pos, "utf-16");
-        new String(bytes, 0, bytes.length, "utf-16");
+        new String(bytes, 0, bytes.length, StandardCharsets.UTF_16);
     }
 
     @SuppressWarnings("resource")
@@ -80,47 +82,39 @@ public class ReaderInputStreamTest {
     }
 
     @Test
-    public void testPreample() throws Exception {
-        byte[] bytes = "".getBytes("utf-16");
+    public void testPreample() {
+        byte[] bytes = "".getBytes(StandardCharsets.UTF_16);
         System.out.println("Preample len is " + bytes.length);
     }
 
     @Test
     public void testIso88591ToUtf8() throws Exception {
-        InputStreamReader fin = null;
-        ReaderInputStream r = null;
-        FileInputStream utf8 = null;
-        try {
-            fin = new InputStreamReader(new FileInputStream(new File(ROOT,
-                    "src/tests/antunit/taskdefs/exec/input/iso8859-1")), "ISO8859_1");
-            r = new ReaderInputStream(fin, "UTF8");
-
-            ByteArrayOutputStream actualOS = new ByteArrayOutputStream();
+        ByteArrayOutputStream actualOS = new ByteArrayOutputStream();
+        try (ReaderInputStream r = new ReaderInputStream(new InputStreamReader(new FileInputStream(new File(ROOT,
+                "src/tests/antunit/taskdefs/exec/input/iso8859-1")), StandardCharsets.ISO_8859_1),
+                StandardCharsets.UTF_8)) {
             int b = r.read();
             while (b > -1) {
                 actualOS.write((byte) b);
                 b = r.read();
             }
+        }
 
-            utf8 = new FileInputStream(new File(ROOT,
-                    "src/tests/antunit/taskdefs/exec/expected/utf-8"));
-            ByteArrayOutputStream expectedOS = new ByteArrayOutputStream();
-            b = utf8.read();
+        ByteArrayOutputStream expectedOS = new ByteArrayOutputStream();
+        try (FileInputStream utf8 = new FileInputStream(new File(ROOT,
+                "src/tests/antunit/taskdefs/exec/expected/utf-8"))) {
+            int b = utf8.read();
             while (b > -1) {
                 expectedOS.write((byte) b);
                 b = utf8.read();
             }
+        }
 
-            byte[] expected = expectedOS.toByteArray();
-            byte[] actual = actualOS.toByteArray();
-            assertEquals("length", expected.length, actual.length);
-            for (int i = 0; i < actual.length; i++) {
-                assertEquals("byte " + i, expected[i], actual[i]);
-            }
-        } finally {
-            FileUtils.close(fin);
-            FileUtils.close(r);
-            FileUtils.close(utf8);
+        byte[] expected = expectedOS.toByteArray();
+        byte[] actual = actualOS.toByteArray();
+        assertEquals("length", expected.length, actual.length);
+        for (int i = 0; i < actual.length; i++) {
+            assertEquals("byte " + i, expected[i], actual[i]);
         }
     }
 
